@@ -8,8 +8,6 @@
 
 #include "httplookup.h"
 
-#include <KIO/Job>
-#include <QDebug>
 #include <QUrlQuery>
 
 namespace KCDDB
@@ -170,4 +168,6 @@ namespace KCDDB
   }
 }
 
+#include "moc_httplookup.cpp"
+
 // vim:tabstop=2:shiftwidth=2:expandtab:cinoptions=(s,U1,m1
